==> gps_0.9.4.orig.tar.gz: gps-0.9.4/importglobals.h <==
/* $Id: importglobals.h,v 1.8 2000/09/29 10:15:36 bergo Exp $ */

#ifndef IMPORTGLOBALS_H
#define IMPORTGLOBALS_H

#include <gtk/gtk.h>
#include "gps.h"
#include "filter.h"
#include "polling.h"

#define POSIXSIG 19

extern gint netcritical;
extern gint nettimeout;
extern gint net_halt_request;

extern gint show_long_names;
extern gint continuum;
extern gint poll_local_only;
extern gint jelly_bar;
extern int  gotgui;

extern ProcessListPoller *list_poller;
extern ProcessDetailsPoller *details_poller;
extern SystemInfoProvider *info_provider;

extern int watch_count;
extern GList *listwatch;
extern GList *detailswatch;
extern GList *sysinfowatch;

extern gint have_filter;
extern struct filter_info fi_work,fi_stru;

extern GList *hostlist_fixed;

extern gint pid_sel;
extern char host_sel[128],this_host[128];

extern GtkWidget *hdlg;
extern gchar col_title[PROCESS_LIST_COLUMNS][10];
extern GtkWidget *status_label[3];

extern gint to_history;

extern char *posixnames[];
extern gint posixvalues[];

extern GtkWindow *MainWindow;

extern char *T_SNT;

extern int c_history_cpu_a;
extern int c_history_cpu_b;
extern int c_history_cpu_c;
extern int c_history_grid;

extern int c_history_swap_a;
extern int c_history_swap_b;
extern int c_history_swap_c;

extern int c_blue_a;
extern int c_blue_b;
extern int c_blue_c;

extern int c_yellow_a;
extern int c_yellow_b;
extern int c_yellow_c;

extern int c_ubox_cpu_a;
extern int c_ubox_cpu_b;
extern int c_ubox_cpu_c;
extern int c_ubox_cpu_d;

extern int c_ubox_mem_a;
extern int c_ubox_mem_b;
extern int c_ubox_mem_c;
extern int c_ubox_mem_d;

extern int c_ubox_uline;
extern int c_ubox_link;
extern int c_ubox_border;
extern int c_ubox_label;

extern char ** pix_mem;
extern char ** pix_swp;

extern int history_interval;
extern int list_interval;

#endif

==> gps_1.1.0.orig.tar.gz: gps-1.1.0/importglobals.h <==
/* $Id: importglobals.h,v 1.10 2001/03/22 18:37:23 bergo Exp $ */

#ifndef IMPORTGLOBALS_H
#define IMPORTGLOBALS_H

#include <gtk/gtk.h>
#include "gps.h"
#include "filter.h"
#include "polling.h"

#define POSIXSIG 19

#define QBAR_TOP    0
#define QBAR_BOTTOM 1

#define QBAR_LEFT   -1
#define QBAR_CENTER 0
#define QBAR_RIGHT  1

extern gint netcritical;
extern gint nettimeout;
extern gint net_halt_request;

extern gint show_long_names;
extern gint continuum;
extern gint poll_local_only;
extern gint jelly_bar;
extern int  gotgui;

extern ProcessListPoller *list_poller;
extern ProcessDetailsPoller *details_poller;
extern SystemInfoProvider *info_provider;

extern int watch_count;
extern GList *listwatch;
extern GList *detailswatch;
extern GList *sysinfowatch;

extern gint have_filter;
extern struct filter_info fi_work,fi_stru;

extern GList *hostlist_fixed;

extern gint pid_sel;
extern char host_sel[128],this_host[128];

extern GtkWidget *hdlg;
extern gchar col_title[PROCESS_LIST_COLUMNS][10];
extern GtkWidget *status_label[3];

extern gint to_history;

extern char *posixnames[];
extern gint posixvalues[];

extern GtkWindow *MainWindow;

extern char *T_SNT;

extern int c_history_cpu_a;
extern int c_history_cpu_b;
extern int c_history_cpu_c;
extern int c_history_grid;

extern int c_history_swap_a;
extern int c_history_swap_b;
extern int c_history_swap_c;

extern int c_blue_a;
extern int c_blue_b;
extern int c_blue_c;

extern int c_yellow_a;
extern int c_yellow_b;
extern int c_yellow_c;

extern int c_ubox_cpu_a;
extern int c_ubox_cpu_b;
extern int c_ubox_cpu_c;
extern int c_ubox_cpu_d;

extern int c_ubox_mem_a;
extern int c_ubox_mem_b;
extern int c_ubox_mem_c;
extern int c_ubox_mem_d;

extern int c_ubox_uline;
extern int c_ubox_link;
extern int c_ubox_border;
extern int c_ubox_label;

extern char ** pix_mem;
extern char ** pix_swp;

extern int history_interval;
extern int list_interval;

extern int quickbar_pos;
extern int quickbar_width;
extern int quickbar_halign;
extern int quickbar_windowed;

#endif
